local HealingTracker = _G.HealingTracker
local DetailsFrame = HealingTracker.DetailsFrame
local LSM = LibStub("LibSharedMedia-3.0")

function DetailsFrame:Init()
end

-- show frame
function DetailsFrame:Show(player)

	local frame = CreateFrame("Frame", "TrackerFrame", UIParent) 
	frame:RegisterForDrag("LeftButton")
	frame:SetSize(800, 450)
	frame:SetMovable(true)
	frame:EnableMouse(true)
	frame:SetPoint("CENTER", UIParent, "CENTER", 0, 70)
	frame:SetBackdrop({bgFile = "Interface\\DialogFrame\\UI-DialogBox-Background-Dark",
						edgeFile = "Interface\\DialogFrame\\UI-DialogBox-Border",
						tile = true, tileSize = 16, edgeSize = 1,
						insets = {left = 1, right = 1, top = 1, bottom = 1}})
	frame:SetBackdropColor(0, 0, 0, 0.90)
	frame:SetFrameStrata("HIGH")
	
	-- window bar
	local windowbarFrame = CreateFrame("Frame", "DetailsWindowBar", frame)
	windowbarFrame:SetSize(796, 24)
	windowbarFrame:EnableMouse(true)
	windowbarFrame:SetBackdrop({bgFile = "Interface\\AddOns\\HealingTracker\\textures\\Flat"})
	windowbarFrame:SetBackdropColor(0.3, 0.3, 0.3, 0.7)
	windowbarFrame:SetPoint("TOPLEFT", frame, "TOPLEFT", 2, -2)
	
	local headerText = windowbarFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	headerText:SetPoint("LEFT", windowbarFrame, "LEFT", 5, 0)
	headerText:SetJustifyH("LEFT")
	headerText:SetFont(LSM:Fetch("font", "2002 Bold"), 11, "")
	headerText:SetTextColor(1, 1, 1, 1)
	headerText:SetWidth(500)
	headerText:SetHeight(24)
	headerText:SetText("Player Details")
	
	local windowCloser = CreateFrame("Button", nil, windowbarFrame)
	windowCloser:SetNormalTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Up")
	windowCloser:SetHighlightTexture("Interface\\Buttons\\UI-Panel-MinimizeButton-Highlight", "ADD")
	windowCloser:SetSize(20, 20)
	windowCloser:SetPoint("RIGHT", windowbarFrame, "RIGHT", -2, 0)
	windowCloser:SetScript("OnClick", function(f) f:GetParent():GetParent():Hide() end)
	
	windowbarFrame:SetScript("OnMouseDown",
					function(self, button)
						if button == "LeftButton" then
							self:GetParent().isMoving = 1
							self:GetParent():StartMoving();
						end
					end)
	windowbarFrame:SetScript("OnMouseUp",
					function(self)
						if self:GetParent().isMoving == 1 then
							self:GetParent():StopMovingOrSizing();
						end
					end)
					
	-- header
	local headerFrame = CreateFrame("Frame", "DetailsFooter", frame)
	headerFrame:SetSize(798, 60)
	headerFrame:SetPoint("TOPLEFT", frame, "TOPLEFT", 1, -26)
	local classIcon = CreateFrame("FRAME", "DetailClassIcon", headerFrame)
	classIcon:SetSize(30, 30)
	classIcon:SetPoint("TOPLEFT", headerFrame, "TOPLEFT", 10, -10)
	local classIconTex = classIcon:CreateTexture()
	classIconTex:SetAllPoints(classIcon)
	local ctt = ClassTextures[player.Class]
	classIconTex:SetTexture("Interface\\AddOns\\HealingTracker\\textures\\"..ctt)
	local playerNameText = headerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	playerNameText:SetPoint("TOPLEFT", headerFrame, "TOPLEFT", 46, -16)
	playerNameText:SetJustifyH("LEFT")
	playerNameText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 15, "")
	playerNameText:SetTextColor(1, 1, 1, 1)
	playerNameText:SetWidth(300)
	playerNameText:SetText(player.Name)
	local spellListText = headerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	spellListText:SetPoint("TOPLEFT", headerFrame, "TOPLEFT", 11, -47)
	spellListText:SetJustifyH("LEFT")
	spellListText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 9, "")
	spellListText:SetTextColor(0.8, 0.8, 0.8, 1)
	spellListText:SetWidth(200)
	spellListText:SetText("Spells")
	local timelineText = headerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	timelineText:SetPoint("TOPLEFT", headerFrame, "TOPLEFT", 256, -47)
	timelineText:SetJustifyH("LEFT")
	timelineText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 9, "")
	timelineText:SetTextColor(0.8, 0.8, 0.8, 1)
	timelineText:SetWidth(200)
	timelineText:SetText("Timeline")
	
	-- footer
	local footerFrame = CreateFrame("Frame", "DetailsFooter", frame)
	footerFrame:SetSize(796, 60)
	footerFrame:SetBackdrop({bgFile = "Interface\\AddOns\\HealingTracker\\textures\\Flat"})
	footerFrame:SetBackdropColor(0.3, 0.3, 0.3, 0.4)
	footerFrame:SetPoint("BOTTOMLEFT", frame, "BOTTOMLEFT", 2, 2)
	
	footerFrame:SetScript("OnMouseDown",
					function(self, button)
						if button == "LeftButton" then
							self:GetParent().isMoving = 1
							self:GetParent():StartMoving();
						end
					end)
	footerFrame:SetScript("OnMouseUp",
					function(self)
						if self:GetParent().isMoving == 1 then
							self:GetParent():StopMovingOrSizing();
						end
					end)
					
	local totalHealTitleText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	totalHealTitleText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 15, -12)
	totalHealTitleText:SetJustifyH("LEFT")
	totalHealTitleText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
	totalHealTitleText:SetTextColor(0.95, 0.8, 0.1, 1)
	totalHealTitleText:SetWidth(150)
	totalHealTitleText:SetText("Total Heal (Hots)")
	
	local aidfulHealTitleText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	aidfulHealTitleText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 175, -12)
	aidfulHealTitleText:SetJustifyH("LEFT")
	aidfulHealTitleText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
	aidfulHealTitleText:SetTextColor(0.95, 0.8, 0.1, 1)
	aidfulHealTitleText:SetWidth(150)
	aidfulHealTitleText:SetText("Aidful Heal (Hots)")
	
	local pointlessHealTitleText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointlessHealTitleText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 335, -12)
	pointlessHealTitleText:SetJustifyH("LEFT")
	pointlessHealTitleText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
	pointlessHealTitleText:SetTextColor(0.95, 0.8, 0.1, 1)
	pointlessHealTitleText:SetWidth(150)
	pointlessHealTitleText:SetText("Pointless Heal (Hots)")
	
	local healRatioText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	healRatioText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 485, -12)
	healRatioText:SetJustifyH("CENTER")
	healRatioText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
	healRatioText:SetTextColor(0.95, 0.8, 0.1, 1)
	healRatioText:SetWidth(50)
	healRatioText:SetText("Percent")
	
	local pointTotalTitleText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointTotalTitleText:SetPoint("TOPRIGHT", footerFrame, "TOPRIGHT", -15, -12)
	pointTotalTitleText:SetJustifyH("RIGHT")
	pointTotalTitleText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
	pointTotalTitleText:SetTextColor(0.95, 0.8, 0.1, 1)
	pointTotalTitleText:SetWidth(80)
	pointTotalTitleText:SetText("Points")
	
	local pointTitleText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointTitleText:SetPoint("TOPRIGHT", footerFrame, "TOPRIGHT", -95, -12)
	pointTitleText:SetJustifyH("CENTER")
	pointTitleText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
	pointTitleText:SetTextColor(0.95, 0.8, 0.1, 1)
	pointTitleText:SetWidth(60)
	pointTitleText:SetText("Emergency")
	
	local pointRTitleText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointRTitleText:SetPoint("TOPRIGHT", footerFrame, "TOPRIGHT", -175, -12)
	pointRTitleText:SetJustifyH("CENTER")
	pointRTitleText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
	pointRTitleText:SetTextColor(0.95, 0.8, 0.1, 1)
	pointRTitleText:SetWidth(50)
	pointRTitleText:SetText("Regular")
	
	local total = player.AidfulHeal + player.PointlessHeal
	local totalHots = player.AidfulPeriodicHeal + player.PointlessPeriodicHeal
	local totalHealText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	totalHealText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 15, -30)
	totalHealText:SetJustifyH("LEFT")
	totalHealText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 14, "")
	totalHealText:SetTextColor(1, 1, 1, 1)
	totalHealText:SetWidth(150)
	totalHealText:SetText(HealingTracker.Helper:ReadableNumber(total + totalHots).. " ("..HealingTracker.Helper:ReadableNumber(totalHots)..")")
	
	local aidfulHealText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	aidfulHealText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 175, -30)
	aidfulHealText:SetJustifyH("LEFT")
	aidfulHealText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 14, "")
	aidfulHealText:SetTextColor(1, 1, 1, 1)
	aidfulHealText:SetWidth(150)
	aidfulHealText:SetText(HealingTracker.Helper:ReadableNumber(player.AidfulHeal + player.AidfulPeriodicHeal).. " ("..HealingTracker.Helper:ReadableNumber(player.AidfulPeriodicHeal)..")")
	
	local pointlessHealText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointlessHealText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 335, -30)
	pointlessHealText:SetJustifyH("LEFT")
	pointlessHealText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 14, "")
	pointlessHealText:SetTextColor(1, 1, 1, 1)
	pointlessHealText:SetWidth(150)
	pointlessHealText:SetText(HealingTracker.Helper:ReadableNumber(player.PointlessHeal + player.PointlessPeriodicHeal).. " ("..HealingTracker.Helper:ReadableNumber(player.PointlessPeriodicHeal)..")")
	
	local totalPointless = player.PointlessHeal + player.PointlessPeriodicHeal
	local totalAidful = player.AidfulHeal + player.AidfulPeriodicHeal
	local totalHeal = totalPointless + totalAidful
	local healRatio = math.floor((totalAidful / totalHeal) * 100)
	if totalAidful == 0 or totalHeal == 0 then
		healRatio = 0
	end
	local healRatioValueText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	healRatioValueText:SetPoint("TOPLEFT", footerFrame, "TOPLEFT", 485, -30)
	healRatioValueText:SetJustifyH("CENTER")
	healRatioValueText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 14, "")
	healRatioValueText:SetTextColor(1, 1, 1, 1)
	healRatioValueText:SetWidth(50)
	healRatioValueText:SetText(healRatio.."%")
	
	local pointTotalText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointTotalText:SetPoint("TOPRIGHT", footerFrame, "TOPRIGHT", -15, -30)
	pointTotalText:SetJustifyH("RIGHT")
	pointTotalText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 22, "")
	pointTotalText:SetTextColor(1, 1, 1, 1)
	pointTotalText:SetWidth(80)
	pointTotalText:SetText((player.TotalMultiply + player.TotalRegular))
	
	local pointText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointText:SetPoint("TOPRIGHT", footerFrame, "TOPRIGHT", -95, -30)
	pointText:SetJustifyH("CENTER")
	pointText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 14, "")
	pointText:SetTextColor(1, 1, 1, 1)
	pointText:SetWidth(60)
	pointText:SetText(player.TotalMultiply)
	
	local pointRText = footerFrame:CreateFontString(nil, nil, "GameFontNormalSmall")
	pointRText:SetPoint("TOPRIGHT", footerFrame, "TOPRIGHT", -175, -30)
	pointRText:SetJustifyH("CENTER")
	pointRText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 14, "")
	pointRText:SetTextColor(1, 1, 1, 1)
	pointRText:SetWidth(50)
	pointRText:SetText(player.TotalRegular)
	
	-- body
	local bodyFrame = CreateFrame("Frame", "BodyFrame", frame)
	bodyFrame:SetSize(798, 230)
	bodyFrame:SetPoint("TOPLEFT", frame, "TOPLEFT", 1, -85)
	bodyFrame:SetBackdrop({bgFile = "Interface\\AddOns\\HealingTracker\\textures\\Flat"})
	bodyFrame:SetBackdropColor(0, 0, 0, 0.2)
	
	-- Spell List Scrolled Frame
	local spellListFrame = CreateFrame("Frame", "TrackerFrame", frame)
	spellListFrame:SetSize(230, 294) 
	spellListFrame:SetPoint("TOPLEFT", frame, "TOPLEFT",0,-90)
	local spellListTexture = spellListFrame:CreateTexture() 
	spellListTexture:SetAllPoints() 
	spellListTexture:SetTexture(.5,.5,.5,1)
	
	spellListSF = CreateFrame("ScrollFrame", nil, spellListFrame) 
	spellListSF:SetPoint("TOPLEFT", 10, -10) 
	spellListSF:SetPoint("BOTTOMRIGHT", -10, 10) 
	local texture = spellListSF:CreateTexture() 
	texture:SetAllPoints() 
	texture:SetTexture(.5,.5,.5,1) 
	spellListFrame.scrollframe = spellListSF 
	 
	spellListSBar = CreateFrame("Slider", nil, spellListSF, "UIPanelScrollBarTemplate") 
	spellListSBar:SetPoint("TOPLEFT", spellListFrame, "TOPRIGHT", 4, -16) 
	spellListSBar:SetPoint("BOTTOMLEFT", spellListFrame, "BOTTOMRIGHT", 4, 16) 
	spellListSBar:SetMinMaxValues(1, 200)
	spellListSBar:SetValueStep(1) 
	spellListSBar.scrollStep = 1
	spellListSBar:SetValue(0) 
	spellListSBar:SetWidth(16) 
	spellListSBar:SetScript("OnValueChanged", 
	function (self, value) 
	self:GetParent():SetVerticalScroll(value) 
	end) 
	local scrollbg = spellListSBar:CreateTexture(nil, "BACKGROUND") 
	scrollbg:SetAllPoints(spellListSBar) 
	scrollbg:SetTexture(0, 0, 0, 0.4) 
	spellListFrame.scrollbar = spellListSBar 
	 
	local spellListContent = CreateFrame("Frame", nil, spellListSF) 
	spellListContent:SetSize(128, 128) 
	spellListSF.spellListContent = spellListContent 
	spellListSF:SetScrollChild(spellListContent)
	
	-- Timeline Scrolled Frame
	local timelineFrame = CreateFrame("Frame", "TimelineFrame", frame)
	timelineFrame:SetSize(540, 230) 
	timelineFrame:SetPoint("TOPLEFT", frame, "TOPLEFT",235,-90)
	local timelineTexture = timelineFrame:CreateTexture() 
	timelineTexture:SetAllPoints()
	timelineFrame:EnableMouse()
	timelineTexture:SetTexture(.5,.5,.5,1)
	
	timelineSF = CreateFrame("ScrollFrame", nil, timelineFrame) 
	timelineSF:SetPoint("TOPLEFT", 10, -10) 
	timelineSF:SetPoint("BOTTOMRIGHT", -10, 10) 
	local ttSFtexture = timelineSF:CreateTexture() 
	ttSFtexture:SetAllPoints() 
	ttSFtexture:SetTexture(.5,.5,.5,1) 
	timelineFrame.scrollframe = timelineSF 
	 
	timelineSBar = CreateFrame("Slider", nil, timelineSF, "UIPanelScrollBarTemplate") 
	timelineSBar:SetPoint("TOPLEFT", timelineFrame, "TOPRIGHT", 4, -16) 
	timelineSBar:SetPoint("BOTTOMLEFT", timelineFrame, "BOTTOMRIGHT", 4, 16) 
	timelineSBar:SetMinMaxValues(1, 200) 
	timelineSBar:SetValueStep(1) 
	timelineSBar.scrollStep = 1
	timelineSBar:SetValue(0) 
	timelineSBar:SetWidth(16) 
	timelineSBar:SetScript("OnValueChanged", 
	function (self, value) 
	self:GetParent():SetVerticalScroll(value) 
	end) 
	local scrollbg2 = timelineSBar:CreateTexture(nil, "BACKGROUND") 
	scrollbg2:SetAllPoints(timelineSBar) 
	scrollbg2:SetTexture(0, 0, 0, 0.4) 
	timelineFrame.scrollbar = timelineSBar 
	 
	local timelineContent = CreateFrame("Frame", nil, timelineSF) 
	timelineContent:SetSize(128, 128)
	timelineSF.timelineContent = timelineContent 
	timelineSF:SetScrollChild(timelineContent)
	
	local si = 0
	local sortedSpells = HealingTracker.Helper:SortSpells(player, true)
	local scaleRatio = -1
	table.foreach(sortedSpells,
		function(k, v)
			local curPoint = v.PointMultiply + v.PointRegular
			if scaleRatio == -1 then
				scaleRatio = 230 / curPoint
			end
			local spdiv = CreateFrame("Frame", nil, spellListContent)
			spdiv:SetPoint("TOPLEFT", spellListContent, "TOPLEFT", 0, si)
			spdiv:SetBackdrop({bgFile = "Interface\\AddOns\\HealingTracker\\textures\\Aluminium"})
			spdiv:SetBackdropColor(1, 1, 1, 0.1)
			spdiv:SetWidth(240)
			spdiv:SetHeight(17)
			
			local spellNameText = spdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
			spellNameText:SetPoint("LEFT", spdiv, "LEFT", 5, 0)
			spellNameText:SetJustifyH("LEFT")
			spellNameText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 9, "")
			spellNameText:SetTextColor(1,1,1,1)
			spellNameText:SetNonSpaceWrap(false)
			spellNameText:SetText(v.Name)
			
			spellNameText:SetWidth(115)
			spellNameText:SetHeight(16)
			spdiv.spellNameText = spellNameText
			
			local spellPointText = spdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
			spellPointText:SetPoint("LEFT", spdiv, "LEFT", 153, 0)
			spellPointText:SetJustifyH("RIGHT")
			spellPointText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
			spellPointText:SetTextColor(1,1,1,1)
			spellPointText:SetWidth(50)
			spellPointText:SetText(curPoint)
			spdiv.spellPointText = spellPointText
	
			local spellAidText = spdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
			spellAidText:SetPoint("LEFT", spdiv, "LEFT", 115, 0)
			spellAidText:SetJustifyH("RIGHT")
			spellAidText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 8, "")
			spellAidText:SetTextColor(1.0, 0.9, 0.3, 1)
			spellAidText:SetWidth(45)
			spellAidText:SetText(HealingTracker.Helper:ReadableNumber(v.AidfulHeal))
			spdiv.spellAidText = spellAidText
			
			local spw = scaleRatio * curPoint
			local spprg = CreateFrame("Frame", nil, spdiv)
			spprg:SetPoint("TOPLEFT", spdiv, "TOPLEFT", 0, 0)
			spprg:SetBackdrop({bgFile = "Interface\\AddOns\\HealingTracker\\textures\\Aluminium"})
			spprg:SetBackdropColor(1, 1, 1, 0.28)
			spprg:SetWidth(spw)
			spprg:SetHeight(17)
			
			spdiv:SetScript("OnEnter",
				function(self, button)
						local tot = v.PointlessHeal + v.AidfulHeal + v.AidfulPeriodicHeal + v.PointlessPeriodicHeal
						local aid = v.AidfulHeal + v.AidfulPeriodicHeal
						GameTooltip:SetOwner(spdiv, "ANCHOR_NONE")
						GameTooltip:SetPoint("TOPLEFT", spdiv, "BOTTOMLEFT", 0, -10)
						GameTooltip:ClearLines()
						GameTooltip:AddLine(v.Name, 0, 1, 0)
						GameTooltip:AddLine("Emergency Point : "..v.PointMultiply, 1, 1, 0)
						GameTooltip:AddLine("Regular Point : "..v.PointRegular, 1, 1, 0)
						GameTooltip:AddLine("Regular / Critical : "..v.Cast.." / "..v.Critical, 1, 1, 1)
						GameTooltip:AddLine("Aidful Heal : "..HealingTracker.Helper:ReadableNumber(v.AidfulHeal), 1, 1, 1)
						GameTooltip:AddLine("Aidful HOTs : "..HealingTracker.Helper:ReadableNumber(v.AidfulPeriodicHeal), 1, 1, 1)
						GameTooltip:AddLine("Pointless Heal : "..HealingTracker.Helper:ReadableNumber(v.PointlessHeal), 1, 1, 1)
						GameTooltip:AddLine("Pointless HOTs : "..HealingTracker.Helper:ReadableNumber(v.PointlessPeriodicHeal), 1, 1, 1)
						local perc = (aid / tot) * 100
						if aid == 0 or tot == 0 then perc = 0 end
						GameTooltip:AddLine("Aidful Heal Percent : "..math.floor(perc).."%", 1, 1, 1)
						GameTooltip:AddLine("Over Heal : "..HealingTracker.Helper:ReadableNumber(v.OverHeal), 1, 1, 1)
						GameTooltip:AddLine("Total Heal : "..HealingTracker.Helper:ReadableNumber(tot), 1, 1, 1)
						GameTooltip:Show()
				end)
			spdiv:SetScript("OnLeave",
				function(self, button)
					GameTooltip:Hide()
				end)
		
			si = si - 18
		end)
	
	local i = 1
	local lastTop = -3
	table.foreach(player.Timeline,
		function(k, v)
			local tcdiv = CreateFrame("Frame", nil, timelineContent)
			tcdiv:SetPoint("TOPLEFT", timelineContent, "TOPLEFT", 15, lastTop)
			tcdiv:SetWidth(500)
			tcdiv:SetHeight(18)
			tcdiv:SetBackdrop({bgFile = "Interface\\AddOns\\HealingTracker\\textures\\Aluminium"})
			if v.IsCooldown then
				tcdiv:SetBackdropColor(0.2, 1, 0.5, 0.24)
			else
				tcdiv:SetBackdropColor(1, 1, 1, 0.1)
			end		
			
			-- time, target, spell, amount, from, to, point

			local timeText = tcdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
			timeText:SetPoint("LEFT", tcdiv, 4, 0)
			timeText:SetJustifyH("LEFT")
			timeText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 9, "")
			timeText:SetTextColor(0.6, 0.6, 0.6, 1)
			timeText:SetWidth(90)
			timeText:SetNonSpaceWrap(false)
			timeText:SetSpacing(8)
			timeText:SetText(HealingTracker.Helper:GetTimeSpan(v.Date))

			local spellText = tcdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
			spellText:SetPoint("LEFT", tcdiv, "LEFT", 60, 0)
			spellText:SetJustifyH("LEFT")
			spellText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
			spellText:SetTextColor(0.9, 0.9, 0.9, 1)
			spellText:SetWidth(150)
			spellText:SetNonSpaceWrap(false)
			spellText:SetSpacing(8)
			spellText:SetHeight(16)
			if v.IsPeriodic and v.IsPeriodic == 1 then
				spellText:SetText(v.SpellName.." (hot)")
			else
				spellText:SetText(v.SpellName)
			end
			
			if v.Target then
				local targetText = tcdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
				targetText:SetPoint("LEFT", tcdiv, "LEFT", 220, 0)
				targetText:SetJustifyH("LEFT")
				targetText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
				targetText:SetTextColor(0.7, 0.7, 0.7, 1)
				targetText:SetWidth(110)
				targetText:SetNonSpaceWrap(false)
				targetText:SetSpacing(8)
				targetText:SetHeight(16)
				targetText:SetText(v.Target)
			end

			if v.IsCooldown then

			else
				local amountText = tcdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
				amountText:SetPoint("LEFT", tcdiv, "LEFT", 325, 0)
				amountText:SetJustifyH("RIGHT")
				amountText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 10, "")
				if v.IsCritical == true then
					amountText:SetTextColor(0.4, 0.7, 1, 1)
				else
					amountText:SetTextColor(0.8, 0.8, 0.8, 1)
				end
				amountText:SetWidth(60)
				amountText:SetNonSpaceWrap(false)
				amountText:SetSpacing(8)
				amountText:SetHeight(16)
				amountText:SetText(HealingTracker.Helper:ReadableNumber(v.Heal))

				local percentText = tcdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
				percentText:SetPoint("LEFT", tcdiv, "LEFT", 400, 0)
				percentText:SetJustifyH("LEFT")
				percentText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 9, "")
				if v.BeforeHP < 10 then
					percentText:SetTextColor(0.1, 1, 0.2, 1)
				elseif v.BeforeHP < 20 then
					percentText:SetTextColor(1, 1, 0.3, 1)
				elseif v.BeforeHP < 30 then
					percentText:SetTextColor(1, 0.8, 0.5, 1)
				elseif v.BeforeHP < 40 then
					percentText:SetTextColor(1, 1, 1, 1)
				else
					percentText:SetTextColor(0.8, 0.8, 0.8, 1)
				end
				percentText:SetWidth(80)
				percentText:SetNonSpaceWrap(false)
				percentText:SetSpacing(8)
				percentText:SetHeight(16)
				percentText:SetText(v.BeforeHP.."% > "..v.AfterHP.."%")

				local pointText = tcdiv:CreateFontString(nil, nil, "GameFontNormalSmall")
				pointText:SetPoint("RIGHT", tcdiv, "RIGHT", -3, 0)
				pointText:SetJustifyH("RIGHT")
				pointText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 12, "")
				if v.Point > 11 then
					pointText:SetTextColor(0.2, 1, 0.2, 1)
				elseif v.Point > 10 then
					pointText:SetTextColor(0.8, 0.8, 0.3, 1)
				elseif v.Point > 5 then
					pointText:SetTextColor(1, 1, 1, 1)
				else
					pointText:SetTextColor(0.8, 0.8, 0.8, 1)
				end
				pointText:SetWidth(190)
				pointText:SetNonSpaceWrap(false)
				pointText:SetSpacing(8)
				pointText:SetText(v.Point.."")
			end
			timelineContent["tc"..i] = tcdiv
			i = i + 1
			lastTop = lastTop - 19
		end)
	
	local timeLineContentH = lastTop * -1
	if timeLineContentH < 300 then timeLineContentH = 300 end
	timelineContent:SetHeight(timeLineContentH)
	timelineSBar:SetMinMaxValues(1, timeLineContentH - 180)
	
	local manaText = frame:CreateFontString(nil, nil, "GameFontNormalSmall")
	manaText:SetPoint("TOPLEFT", frame, "TOPLEFT", 260, -312)
	manaText:SetJustifyH("LEFT")
	manaText:SetFont(LSM:Fetch("font", "Friz Quadrata TT"), 9, "")
	manaText:SetTextColor(0.8, 0.8, 0.8, 1)
	manaText:SetWidth(200)
	manaText:SetText("Mana")

	local manaFrame = CreateFrame("FRAME", "ManaFrame", frame)
	manaFrame:SetPoint("TOPLEFT", frame, "TOPLEFT", 260, -325)
	manaFrame:SetSize(525, 60)
	manaFrame:SetBackdrop({bgFile = "Interface\\Tooltips\\UI-Tooltip-Background", tile = true, tileSize = 50})
	manaFrame:SetBackdropColor(0, 0, 0, 1)

	local manaLogs = {}
	local fi = 100
	for k=0,740 do
		manaLogs[k] = fi
		fi = fi - (math.random(0,10) / 30)
		if fi < 0 then
			fi = 80
		end
	end

	manaLogs = player.Mana
	if manaLogs then
		local seconds = #manaLogs
		local pixels = 525
		local ratio = seconds / pixels

		for i = 0, pixels-1 do

			local mi = math.floor(i * ratio)
			local mvalue = manaLogs[mi]
			local mh = (100 - mvalue) / -2

			local dot = CreateFrame("FRAME", "mdot"..i, manaFrame)
			dot:SetBackdrop({bgFile = "Interface\\AddOns\\HealingTracker\\textures\\line3", tile = false})

			local cr = 1
			local cg = 1
			local cb = 0
			if mvalue < 50 then
				cg = (mvalue * 2) / 100
				cr = 1
			else
				cr = (100 - mvalue) / 50
				cg = 1
			end

			dot:SetBackdropColor(cr, cg, cb, 1)
			dot:SetPoint("TOPLEFT", manaFrame, "TOPLEFT", i, mh)
			dot:SetSize(1, 10)
			
			dot:SetScript("OnEnter",
			function(self, button)
				GameTooltip:SetOwner(dot, "ANCHOR_NONE")
				GameTooltip:SetPoint("BOTTOMRIGHT", dot, "TOPLEFT")
				GameTooltip:ClearLines()
				GameTooltip:AddLine("Time: "..HealingTracker.Helper:GetTimeSpan(mi), 1, 1, 0)
				GameTooltip:AddLine("Mana: "..math.floor(mvalue).."%", 0.2, 0.3, 1)
				GameTooltip:Show()
			end)
			dot:SetScript("OnLeave", function(self, button) GameTooltip:Hide() end)

		end
	end
	
	frame:Show()
end

function DetailsFrame:Hide()
end

function DetailsFrame:Reset()
end

function DetailsFrame:Refresh()
end
